pub struct Increment<T>(pub T);Expand description
A derangement d(x) = x + increment.
This is the standard padding function for sponge constructions. A derangement has no fixed points (d(x) != x for all x), which holds as long as the stored increment is non-zero.
ⓘ
Increment(BabyBear::ONE) // d(x) = x + 1 for field elements
Increment(1u64) // d(x) = x + 1 for raw integersTuple Fields
0: TTrait Implementations
impl<T: Copy> Copy for Increment<T>
impl<T: Clone + Sync + Send + Add<Output = T>> Derangement<T> for Increment<T>