MerkleCap

Struct MerkleCap 

pub struct MerkleCap<F, Digest> { /* private fields */ }
The Merkle cap of height h of a Merkle tree is the h-th layer (from the root) of the tree. It can be used in place of the root to verify Merkle paths, which are h elements shorter.

A cap of height 0 contains a single element (the root), while a cap of height h contains 2^h elements. The Digest type is the full digest (e.g. [W; DIGEST_ELEMS]).

Implementations

Source

impl<F, Digest> MerkleCap<F, Digest>

pub fn new(cap: Vec<Digest>) -> Self

Create a new MerkleCap from a vector of digests.

pub const fn num_roots(&self) -> usize

Returns the number of digests in the cap.

pub const fn height(&self) -> usize

Returns the height of the cap (log2 of the number of elements). A cap with 1 element has height 0, a cap with 2 elements has height 1, etc.

pub fn roots(&self) -> &[Digest]

Returns a reference to the underlying slice of digests.

pub fn into_roots(self) -> Vec<Digest>

Flattens the cap into a single vector of digest words.