pub struct MerkleCap<F, Digest> { /* private fields */ }Expand description
The Merkle cap of height h of a Merkle tree is the h-th layer (from the root) of the tree.
It can be used in place of the root to verify Merkle paths, which are h elements shorter.
A cap of height 0 contains a single element (the root), while a cap of height h contains
2^h elements. The Digest type is the full digest (e.g. [W; DIGEST_ELEMS]).
Implementations
Sourceimpl<F, Digest> MerkleCap<F, Digest>
impl<F, Digest> MerkleCap<F, Digest>